var searchData=
[
  ['installation_20安裝_0',['Installation 安裝',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md3',1,'']]],
  ['introduction_20介紹_1',['Introduction 介紹',['../dir_049daeb3fb75c899e2b4b691ba1381de.html#autotoc_md1',1,'']]],
  ['invalidformat_2',['InvalidFormat',['../classopencc_1_1_invalid_format.html',1,'opencc']]],
  ['invalidtextdictionary_3',['InvalidTextDictionary',['../classopencc_1_1_invalid_text_dictionary.html',1,'opencc']]],
  ['invalidutf8_4',['InvalidUTF8',['../classopencc_1_1_invalid_u_t_f8.html',1,'opencc']]],
  ['islineendingorfileending_5',['IsLineEndingOrFileEnding',['../classopencc_1_1_u_t_f8_util.html#a008b85311545f43a7a3c14e304004266',1,'opencc::UTF8Util']]],
  ['isnull_6',['IsNull',['../classopencc_1_1_optional.html#a1e0bf8b941446d82796cfa0e0aa413de',1,'opencc::Optional']]],
  ['iterator_7',['iterator',['../classopencc_1_1_segments_1_1iterator.html',1,'opencc::Segments']]]
];
